%DECODIFICADOR LTP.
%function dp=ltpd(Nc,bc,dpd)
%Entradas:
%Nc:término de autocorrelación codificado.
%bc:ganancia codificada.
%dpd:120 muestras anteriores recontruidas.
%Salidas:
%dp:señal sin envolvente de salida.
function dp=ltpd(Nc,bc,dpd)
[N,b]=ltpdec(Nc,bc);%decodificamos los coeficientes LTP.
dp=b*dpd((121-N):(160-N));%calculamos el pitch de la señal.
